class trigger::params {

    $version = "1.4.4"
    $packages = ""

    # This is where Trigger should look for its files.
    $prefix = "/etc/trigger"

    # Set to True to enable GPG Authentication
    # Set to False to use the old .tackf encryption method.
    # Should be False unless instructions/integration is ready for GPG
    $use_gpg_auth = False

    # This is used for old auth method. It sucks and needs to die.
    $user_home = "os.getenv('HOME')"
    $tacacsrc = "os.getenv('TACACSRC', os.path.join(USER_HOME, '.tacacsrc'))"
    $tacacsrc_keyfile = "os.getenv('TACACSRC_KEYFILE', os.path.join(PREFIX, '.tackf'))"
    $tacacsrc_passphrase = "pizza is awesome son"

    # Default login realm to store user credentials (username, password) for
    # general use within the .tacacsrc
    $default_realm = "aol"

    # List of plugins allowed to be importd by Commando. Plugins should be listed as
    # strings depicting the absolute paths.
    #
    # e.g. ['trigger.contrib.config_device', 'trigger.contrib.show_clock', 'bacon cool_plugin']
    #
    # Currently config_device and execute_commands are automatically imported.
    $builtin_plugins = [
        "trigger.contrib.commando.plugins.config_device",
        "trigger.contrib.commando.plugins.show_clock",
        "trigger.contrib.commando.plugins.show_version",
        ]

    $commando_plugins = $builtin_plugins

    # Location of firewall policies
    $firewall_dir = "/data/firewalls"

    # Location of tftproot.
    $tftproot_dir = "/data/tftproot"
    $tftp_host = ""

    # Add internally owned networks here. All network blocks owned/operated and
    # considered part of your network should be included.
    $internal_networks = [
        "10.0.0.0/8",
        "172.16.0.0/12",
        "192.168.0.0/16",
         ]

    # For backwards compatibility
    $valid_vendors = $supported_vendors

    $vendor_info = {
        "a10" =>
        {
            "name" =>  "A10 NETWORKS",
            "splats"    =>  '[ "SWITCH" ]',
            "deftype"   =>  '[ "SWITCH" ]',
        },
        "arista" =>
        {
            "name" =>  "ARISTA NETWORKS",
            "splats"    =>  '[ "SWITCH" ]',
            "deftype"   =>  '[ "SWITCH" ]',
        },
        "aruba" =>
        {
            "name" =>  "ARUBA NETWORKS",
            "splats"    =>  '[ "SWITCH" ]',
            "deftype"   =>  '[ "SWITCH" ]',
        },
        "brocade" =>
        {
            "name" =>  "BROCADE",
            "splats"    =>  '[ "ROUTER", "SWITCH" ]',
            "deftype"   =>  '[ "SWITCH" ]',
        },
        "cisco" =>
        {
            "name" =>  "CISCO SYSTEMS",
            "splats"    =>  '[ "ROUTER", "SWITCH" ]',
            "deftype"   =>  '[ "ROUTER" ]',
        },
        "citrix" =>
        {
            "name" =>  "CITRIX",
            "splats"    =>  '[ "SWITCH" ]',
            "deftype"   =>  '[ "SWITCH" ]',
        },
        "dell" =>
        {
            "name" =>  "DELL",
            "splats"    =>  '[ "SWITCH" ]',
            "deftype"   =>  '[ "SWITCH" ]',
        },
        "f5" =>
        {
            "name" =>  "F5 NETWORKS",
            "splats"    =>  '[ "LOAD BALANCING", "SWITCH" ]',
            "deftype"   =>  '[ "LOAD BALANCING" ]',
        },
        "force10" =>
        {
            "name" =>  "FORCE10",
            "splats"    =>  '[ "ROUTER", "SWITCH" ]',
            "deftype"   =>  '[ "ROUTER" ]',
        },
        "foundry" =>
        {
            "name" =>  "FOUNDRY",
            "splats"    =>  '[ "ROUTER", "SWITCH" ]',
            "deftype"   =>  '[ "SWITCH" ]',
        },
        "juniper" =>
        {
            "name" =>  "JUNIPER",
            "splats"    =>  '[ "FIREWALL", "ROUTER", "SWITCH" ]',
            "deftype"   =>  '[ "ROUTER" ]',
        },
        "mrv" =>
        {
            "name" =>  "MRV",
            "splats"    =>  '[ "CONSOLE SERVER", "SWITCH" ]',
            "deftype"   =>  '[ "CONSOLE SERVER" ]',
        },
        "netscreen" =>
        {
            "name" =>  "NETSCREEN TECHNOLOGIES",
            "splats"    =>  '[ "FIREWALL" ]',
            "deftype"   =>  '[ "FIREWALL" ]',
        },
        "paloalto" =>
        {
            "name" =>  "PALO ALTO NETWORKS",
            "splats"    =>  '[ "FIREWALL" ]',
            "deftype"   =>  '[ "FIREWALL" ]',
        },
    # A mapping of manufacturer attribute values to canonical vendor name used by
    # Trigger. These single-word, lowercased canonical names are used throughout
    # Trigger.
    #
    # If your internal definition differs from the UPPERCASED ones specified below
    # (which they probably do, customize them here.

    $vendor_map = {
        "A10 NETWORKS"              => "a10",
        "ARISTA NETWORKS"           => "arista",
        "ARUBA NETWORKS"            => "aruba",
        "BROCADE"                   => "brocade",
        "CISCO SYSTEMS"             => "cisco",
        "CITRIX"                    => "citrix",
        "DELL"                      => "dell",
        "F5 NETWORKS"               => "f5",
        "FORCE10"                   => "force10",
        "FOUNDRY"                   => "foundry",
        "JUNIPER"                   => "juniper",
        "MRV"                       => "mrv",
        "NETSCREEN TECHNOLOGIES"    => "netscreen",
        "PALO ALTO NETWORKS"        => "paloalto",
    }

    # A dictionary keyed by manufacturer name containing a list of the device types
    # for each that is officially supported by Trigger.
    $supported_platforms = {
        "a10"       => '[ "SWITCH" ]',
        "arista"    => '[ "SWITCH" ]' ,
        "aruba"     => '[ "SWITCH" ]',
        "brocade"   => '[ "ROUTER", "SWITCH" ]',
        "cisco"     => '[ "ROUTER", "SWITCH" ]',
        "citrix"    => '[ "SWITCH" ]',
        "dell"      => '[ "SWITCH" ]',
        "f5"        => '[ "LOAD BALANCING, ", "SWITCH" ]',
        "force10"   => '[ "ROUTER", "SWITCH" ]',
        "foundry"   => '[ "ROUTER", "SWITCH" ]',
        "juniper"   => '[ "FIREWALL", "ROUTER", "SWITCH" ]',
        "mrv"       => '[ "CONSOLE SERVER", "SWITCH" ]',
        "netscreen" => '[ "FIREWALL" ]',
        "paloalto"  => '[ "FIREWALL" ]',
    }
    # The tuple of support device types
    $supported_types = [
        "CONSOLE SERVER",
        "FIREWALL",
        "DWDM",
        "LOAD BALANCING",
        "ROUTER",
        "SWITCH",
    ]
    # A mapping of of vendor names to the default device type for each in the
    # event that a device object is created and the deviceType attribute isn't set
    # for some reason.
    $default_types = {
        "a10"       => "SWITCH",
        "arista"    => "SWITCH",
        "aruba"     => "SWITCH",
        "brocade"   => "SWITCH",
        "citrix"    => "SWITCH",
        "cisco"     => "ROUTER",
        "dell"      => "SWITCH",
        "f5"        => "LOAD BALANCING",
        "force10"   => "ROUTER",
        "foundry"   => "SWITCH",
        "juniper"   => "ROUTER",
        "mrv"       => "CONSOLE SERVER",
        "netscreen" => "FIREWALL",
        "paloalto"  => "FIREWALL",
    }
    # When a vendor is not explicitly defined within `DEFAULT_TYPES`, fallback to
    # this type.
    $fallback_type = "ROUTER"

    # Default timeout in seconds for commands executed during a session.  If a
    # response is not received within this window, the connection is terminated.
    $default_timeout = "5 * 60"

    # Default timeout in seconds for initial telnet connections.
    $telnet_timeout  = 60

    # Whether or not to allow telnet fallback
    $telnet_enabled = True

    # Default port for SSH
    $ssh_port = 22

    # Default port for Telnet
    $telnet_port = 23

    # A mapping of vendors to the types of devices for that vendor for which you
    # would like to disable interactive (pty) SSH sessions, such as when using
    # bin/gong.
    $ssh_pty_disabled = {
        "dell" => "SWITCH",
    }

    # A mapping of vendors to the types of devices for that vendor for which you
    # would like to disable asynchronous (NON-interactive) SSH sessions, such as
    # when using twister or Commando to remotely control a device.
    $ssh_async_disabled = {
        "dell"      => "SWITCH",
        "foundry"   => "SWITCH",
    }

    # Vendors that basically just emulate Cisco's IOS and can be treated
    # accordingly for the sake of interaction.
    $ioslike_vendors = [
        "a10",
        "arista",
        "aruba",
        "brocade",
        "cisco",
        "dell",
        "force10",
        "foundry",
    ]

    # The file path where .gorc is expected to be found.
    $gorc_file = "~/.gorc"

    # The only root commands that are allowed to be executed when defined within
    # ``~.gorc``. They will be filtered out by `~trigger.gorc.filter_commands()`.
    $gorc_allowed_commands = [
        "cli",
        "enable",
        "exit",
        "get",
        "monitor",
        "ping",
        "quit",
        "set",
        "show",
        "start",
        "term",
        "terminal",
        "traceroute",
        "who",
        "whoami"
    ]

    # Change this to False to skip the loading of ACLs globally
    # (not recommended)
    $with_acls = True

    # Path to the explicit module file for autoacl.py so that we can still perform
    # 'from trigger.acl.autoacl import autoacl' without modifying sys.path.
    $autoacl_file = "os.environ.get(\'AUTOACL_FILE\', os.path.join(PREFIX, \'autoacl.py\'))"

    # A tuple of data loader classes, specified as strings. Optionally, a tuple can
    # be used instead of a string. The first item in the tuple should be the
    # Loader's module, subsequent items are passed to the Loader during
    # initialization.
    $netdevices_loaders = [
        "trigger.netdevices.loaders.filesystem.XMLLoader",
        "trigger.netdevices.loaders.filesystem.JSONLoader",
        "trigger.netdevices.loaders.filesystem.SQLiteLoader",
        "trigger.netdevices.loaders.filesystem.RancidLoader",
        "trigger.netdevices.loaders.filesystem.CSVLoader",
    ]

    # A path or URL to netdevices device metadata source data, which is used to
    # populate trigger.netdevices.NetDevices. For more information on this, see
    # NETDEVICES_LOADERS.
    $netdevices_source = "os.environ.get('NETDEVICES_SOURCE\', os.path.join(PREFIX,'netdevices.xml'))"

    # Whether to treat the RANCID root as a normal instance, or as the root to
    # multiple instances. This is only checked when using RANCID as a data source.
    $rancid_recurse_subdirs = "os.environ.get('RANCID_RECURSE_SUBDIRS', False)"

    # Valid owning teams (e.g. device.owningTeam) go here. These are examples and should be
    # changed to match your environment.
    $valid_owners = [
        "Data Center",
        "Backbone Engineering",
        "Enterprise Networking",
    ]

    # Fields and values defined here will dictate which Juniper devices receive a
    # ``commit-configuration full`` when populating ``NetDevice.commit_commands`.
    # The fields and values must match the objects exactly or it will fallback to
    # ``commit-configuration``.
    $juniper_full_commit_fields = {
        "deviceType" => "SWITCH",
        "make" => "EX4200",
    }

    # Specially-defined, per-vendor prompt patterns. If a vendor isn't defined here,
    # try to use IOSLIKE_PROMPT_PAT or fallback to DEFAULT_PROMPT_PAT.
    $prompt_patterns = {
        "aruba"     => "r\'\\(\\S+\\)(?: \\(\\S+\\))?\\s?#$\'",
        "citrix"    => "r\'\\sDone\\n\$\'",
        "f5"        => "r\'.*\\(tmos\\).*?#\\s{1,2}\\r?\$\'",
        "juniper"   => "r\'\\S+\\@\\S+(?:\\>|#)\\s\$\'",
        "mrv"       => "r\'\\r\\n?.*(?:\\:\\d{1})?\\s\\>\\>?\$\'",
        "netscreen" => "r\'(\\w+?:|)[\\w().-]*\\(?([\\w.-])?\\)?\\s*->\\s*\$\'",
        "paloalto"  => "r'\\r\\n\\S+(?:\\>|#)\\s?\$\'",
    }

    # When a pattern is not explicitly defined for a vendor, this is what we'll try
    # next (since most vendors are in fact IOS-like)
    $ioslike_prompt_pat = "r\'\\S+(\\(config(-[a-z:1-9]+)?\\))?#\\s?\$\'"
    $ioslike_enable_pat = "r\'\\S+(\\(config(-[a-z:1-9]+)?\\))?>\\s?\$\'"

    # Generic prompt to match most vendors. It assumes that you'll be greeted with
    # a "#" prompt.
    $default_prompt_pat = "r\'\\S+#\\s?\$\'"

    # Path of the explicit module file for bounce.py containing custom bounce
    # window mappings.
    $bounce_file = "os.environ.get(\'BOUNCE_FILE\', os.path.join(PREFIX, \'bounce.py\'))"

    # Default bounce timezone. All BounceWindow objects are configured using
    # US/Eastern for now.
    $bounce_default_tz = "US/Eastern"

    # The default fallback window color for bounce windows. Must be one of
    # ('green', 'yellow', or 'red').
    #
    #     green: Low risk
    #    yellow: Medium risk
    #       red: High risk
    $bounce_default_color = "red"

    # Redis master server. This will be used unless it is unreachable.
    $redis_host = "127.0.0.1"

    # The Redis port. Default is 6379.
    $redis_port = 6379

    # The Redis DB. Default is 0.
    $redis_db = 0

    # These are self-explanatory, I hope. Use the ``init_task_db`` to initialize
    # your database after you've created it! :)
    $database_engine = "mysql"
    $database_name = ""
    $database_user = ""
    $database_password = ""
    $database_host = ""
    $database_port = ""

    # Whether to allow multi-line comments to be used in Juniper firewall filters.
    # Defaults to False.
    $allow_juniper_multiline_comments = False

    # FILTER names of ACLs that should be skipped or ignored by tools
    # NOTE: These should be the names of the filters as they appear on devices. We
    # want this to be mutable so it can be modified at runtime.
    $ignored_acls = []

    # FILE names ACLs that shall not be modified by tools
    # NOTE: These should be the names of the files as they exist in FIREWALL_DIR.
    # Trigger expects ACLs to be prefixed with 'acl.'.  These are examples and
    # should be replaced.
    $nonmod_acls  = []

    # Mapping of real IP to external NAT. This is used by load_acl in the event
    # that a TFTP or connection from a real IP fails or explicitly when passing the
    # --no-vip flag.
    # format: {local_ip: external_ip}
    $vips = {}

    # Any FILTER name (not filename) in this list will be skipped during automatic loads.
    $autoload_blacklist = []

    # Assign blacklist to filter for backwards compatibility
    $autoload_filter = $autoload_blacklist

    # Modify this if you want to create a list that if over the specified number of
    # routers will be treated as bulk loads.
    #
    # Format:
    # { 'filter_name': threshold_count }
    $autoload_filter_thresh = {}

    # Any ACL applied on a number of devices >= to this number will be treated as
    # bulk loads.
    $autoload_bulk_thresh = 10

    # Add an acl:max_hits here if you want to override BULK_MAX_HITS_DEFAULT
    # Keep in mind this number is PER EXECUTION of load_acl --auto (typically once
    # per hour or 3 per bounce window).
    #
    # 1 per load_acl execution; ~3 per day, per bounce window
    # 2 per load_acl execution; ~6 per day, per bounce window
    # etc.
    #
    # Format:
    # { 'filter_name': max_hits }
    $bulk_max_hits = {}

    # If an ACL is bulk but not in BULK_MAX_HITS, use this number as max_hits
    $bulk_max_hits_default = 1

    # This variable should be a function that returns data for your on-call engineer, or
    # failing that None.  The function should return a dictionary that looks like
    # this:
    #
    # {'username': 'joegineer',
    #  'name': 'Joe Engineer',
    #  'email': 'joe.engineer@example.notreal'}
    #
    # If you don't want to return this information, have it return None.
    $get_current_oncall = "lambda x=None: x"

    # Email sender for integrated tools. Usually a good idea to make this a
    # no-reply address.
    $email_sender = "nobody@not.real"

    # Who to email when things go well (e.g. load_acl --auto)
    $success_emails = [ "neteng@example.com",]

    # Who to email when things go not well (e.g. load_acl --auto)
    $failure_emails = [ "primarypager@example.com", "secondarypager@example.com",]

    # The default sender for integrated notifications. This defaults to the fqdn
    # for the localhost.
    $notification_sender = "socket.gethostname()"

    # Destinations (hostnames, addresses) to notify when things go well.
    $success_recipients = [ "foo.example.com", ]

    # Destinations (hostnames, addresses) to notify when things go not well.
    $failure_recipients = [ "socket.gethostname()" ]

    # This is a list of fully-qualified paths. Each path should end with a callable
    # that handles a notification event and returns ``True`` in the event of a
    # successful notification, or ``None``.
    $notification_handlers = [ "trigger.utils.notifications.handlers.email_handler",]

}
